@@ -2,6 +2,7 @@ require 'test_helper'
 
 class ZipFileTest < MiniTest::Test
   include CommonZipFileFixture
+  include ZipEntryData
 
   OK_DELETE_FILE = 'test/data/generated/okToDelete.txt'
   OK_DELETE_MOVED_FILE = 'test/data/generated/okToDeleteMoved.txt'
@@ -40,6 +41,26 @@ class ZipFileTest < MiniTest::Test
     assert_equal(2, zfRead.entries.length)
   end
 
+  def test_create_from_scratch_with_old_create_parameter
+    comment = 'a short comment'
+
+    zf = ::Zip::File.new(EMPTY_FILENAME, 1)
+    zf.get_output_stream('myFile') { |os| os.write 'myFile contains just this' }
+    zf.mkdir('dir1')
+    zf.comment = comment
+    zf.close
+
+    zfRead = ::Zip::File.new(EMPTY_FILENAME)
+    assert_equal(comment, zfRead.comment)
+    assert_equal(2, zfRead.entries.length)
+  end
+
+  def test_get_input_stream_stored_with_gpflag_bit3
+    ::Zip::File.open('test/data/gpbit3stored.zip') do |zf|
+      assert_equal("foo\n", zf.read("foo.txt"))
+    end
+  end
+
   def test_get_output_stream
     entryCount = nil
     ::Zip::File.open(TEST_ZIP.zip_name) do |zf|
@@ -56,7 +77,7 @@ class ZipFileTest < MiniTest::Test
       assert_equal(entryCount + 1, zf.size)
       assert_equal('Putting stuff in data/generated/empty.txt', zf.read('test/data/generated/empty.txt'))
 
-      custom_entry_args = [ZipEntryTest::TEST_COMMENT, ZipEntryTest::TEST_EXTRA, ZipEntryTest::TEST_COMPRESSED_SIZE, ZipEntryTest::TEST_CRC, ::Zip::Entry::STORED, ZipEntryTest::TEST_SIZE, ZipEntryTest::TEST_TIME]
+      custom_entry_args = [TEST_COMMENT, TEST_EXTRA, TEST_COMPRESSED_SIZE, TEST_CRC, ::Zip::Entry::STORED, TEST_SIZE, TEST_TIME]
       zf.get_output_stream('entry_with_custom_args.txt', nil, *custom_entry_args) do |os|
         os.write 'Some data'
       end
@@ -82,6 +103,13 @@ class ZipFileTest < MiniTest::Test
     end
   end
 
+  def test_open_buffer_with_string
+    string = File.read('test/data/rubycode.zip')
+    ::Zip::File.open_buffer string do |zf|
+      assert zf.entries.map { |e| e.name }.include?('zippedruby1.rb')
+    end
+  end
+
   def test_open_buffer_with_stringio
     string_io = StringIO.new File.read('test/data/rubycode.zip')
     ::Zip::File.open_buffer string_io do |zf|
@@ -89,6 +117,63 @@ class ZipFileTest < MiniTest::Test
     end
   end
 
+  def test_close_buffer_with_stringio
+    string_io = StringIO.new File.read('test/data/rubycode.zip')
+    zf = ::Zip::File.open_buffer string_io
+    assert_nil zf.close
+  end
+
+  def test_open_buffer_no_op_does_not_change_file
+    Dir.mktmpdir do |tmp|
+      test_zip = File.join(tmp, 'test.zip')
+      FileUtils.cp 'test/data/rubycode.zip', test_zip
+
+      # Note: this may change the file if it is opened with r+b instead of rb.
+      # The 'extra fields' in this particular zip file get reordered.
+      File.open(test_zip, 'rb') do |file|
+        Zip::File.open_buffer(file) do |zf|
+          nil # do nothing
+        end
+      end
+
+      assert_equal \
+        File.binread('test/data/rubycode.zip'),
+        File.binread(test_zip)
+    end
+  end
+
+  def test_open_buffer_close_does_not_change_file
+    Dir.mktmpdir do |tmp|
+      test_zip = File.join(tmp, 'test.zip')
+      FileUtils.cp 'test/data/rubycode.zip', test_zip
+
+      File.open(test_zip, 'rb') do |file|
+        zf = Zip::File.open_buffer(file)
+        refute zf.commit_required?
+        assert_nil zf.close
+      end
+
+      assert_equal \
+        File.binread('test/data/rubycode.zip'),
+        File.binread(test_zip)
+    end
+  end
+
+  def test_open_buffer_with_io_and_block
+    File.open('test/data/rubycode.zip') do |io|
+      io.set_encoding(Encoding::BINARY) # not strictly required but can be set
+      Zip::File.open_buffer(io) do |zip_io|
+        # left empty on purpose
+      end
+    end
+  end
+
+  def test_open_buffer_without_block
+    string_io = StringIO.new File.read('test/data/rubycode.zip')
+    zf = ::Zip::File.open_buffer string_io
+    assert zf.entries.map { |e| e.name }.include?('zippedruby1.rb')
+  end
+
   def test_cleans_up_tempfiles_after_close
     zf = ::Zip::File.new(EMPTY_FILENAME, ::Zip::File::CREATE)
     zf.get_output_stream('myFile') do |os|
@@ -119,17 +204,37 @@ class ZipFileTest < MiniTest::Test
                                 zfRead.get_input_stream(entryName) { |zis| zis.read })
   end
 
-  def test_recover_permissions_after_add_files_to_archive
-    srcZip = TEST_ZIP.zip_name
-    ::File.chmod(0664, srcZip)
+  def test_add_stored
     srcFile = 'test/data/file2.txt'
     entryName = 'newEntryName.rb'
-    assert_equal(::File.stat(srcZip).mode, 0100664)
+    assert(::File.exist?(srcFile))
+    zf = ::Zip::File.new(EMPTY_FILENAME, ::Zip::File::CREATE)
+    zf.add_stored(entryName, srcFile)
+    zf.close
+
+    zfRead = ::Zip::File.new(EMPTY_FILENAME)
+    entry = zfRead.entries.first
+    assert_equal('', zfRead.comment)
+    assert_equal(1, zfRead.entries.length)
+    assert_equal(entryName, entry.name)
+    assert_equal(File.size(srcFile), entry.size)
+    assert_equal(entry.size, entry.compressed_size)
+    assert_equal(::Zip::Entry::STORED, entry.compression_method)
+    AssertEntry.assert_contents(srcFile,
+                                zfRead.get_input_stream(entryName) { |zis| zis.read })
+  end
+
+  def test_recover_permissions_after_add_files_to_archive
+    srcZip = TEST_ZIP.zip_name
+    ::File.chmod(0o664, srcZip)
+    srcFile = 'test/data/file2.txt'
+    entryName = 'newEntryName.rb'
+    assert_equal(::File.stat(srcZip).mode, 0o100664)
     assert(::File.exist?(srcZip))
     zf = ::Zip::File.new(srcZip, ::Zip::File::CREATE)
     zf.add(entryName, srcFile)
     zf.close
-    assert_equal(::File.stat(srcZip).mode, 0100664)
+    assert_equal(::File.stat(srcZip).mode, 0o100664)
   end
 
   def test_add_existing_entry_name
@@ -213,7 +318,7 @@ class ZipFileTest < MiniTest::Test
       zf.mkdir('test')
       arr << 'test/'
       arr_renamed << 'Ztest/'
-      %w(a b c d).each do |f|
+      %w[a b c d].each do |f|
         zf.get_output_stream("test/#{f}") { |file| file.puts 'aaaa' }
         arr << "test/#{f}"
         arr_renamed << "Ztest/#{f}"
@@ -308,7 +413,7 @@ class ZipFileTest < MiniTest::Test
 
   def test_replace_non_entry
     entryToReplace = 'nonExistingEntryname'
-    ::Zip::File.open(TEST_ZIP.zip_name) do  |zf|
+    ::Zip::File.open(TEST_ZIP.zip_name) do |zf|
       assert_raises(Errno::ENOENT) { zf.replace(entryToReplace, 'test/data/file2.txt') }
     end
   end
@@ -326,7 +431,7 @@ class ZipFileTest < MiniTest::Test
     zfRead.close
 
     zf.close
-    res = system("unzip -t #{TEST_ZIP.zip_name}")
+    res = system("unzip -tqq #{TEST_ZIP.zip_name}")
     assert_equal(res, true)
   end
 
@@ -342,7 +447,7 @@ class ZipFileTest < MiniTest::Test
     zf2 = ::Zip::File.open(filename)
     assert(zf2.entries.detect { |e| e.name == 'test1.txt' } != nil)
     assert(zf2.entries.detect { |e| e.name == 'test2.txt' } != nil)
-    res = system("unzip -t #{filename}")
+    res = system("unzip -tqq #{filename}")
     assert_equal(res, true)
   end
 
@@ -413,7 +518,6 @@ class ZipFileTest < MiniTest::Test
       filename_to_remove = originalEntries.map(&:to_s).find { |name| name.match('longBinary') }
       zf.remove(filename_to_remove)
       assert_not_contains(zf, filename_to_remove)
-
     ensure
       zf.close
     end
@@ -528,9 +632,8 @@ class ZipFileTest < MiniTest::Test
   end
 
   def test_empty_zip
-    puts `touch empty.zip`
     assert_raises(::Zip::Error) do
-      ::Zip::File.open('empty.zip')
+      ::Zip::File.open(TestFiles::NULL_FILE)
     end
   end
 
@@ -538,7 +641,7 @@ class ZipFileTest < MiniTest::Test
     entry_count = 0
     File.open 'test/data/oddExtraField.zip', 'rb' do |zip_io|
       Zip::File.open_buffer zip_io.read do |zip|
-        zip.each do |zip_entry|
+        zip.each do |_zip_entry|
           entry_count += 1
         end
       end
